@@ -11,6 +11,10 @@ pub trait INotificationsQueue {
     fn get_notification(&self) -> ContentNotification;
 }
 
+pub trait Constructor {
+    fn new(context: &Context, backend_endpoint: &String, frontend_endpoint: &String) -> Self;
+}
+
 pub struct NotificationsQueue {
     context: Context,
     backend_endpoint: String,
@@ -44,3 +48,13 @@ impl INotificationsQueue for NotificationsQueue {
     }
 }
 
+impl Constructor for NotificationsQueue {
+    fn new(context: &Context, backend_endpoint: &String, frontend_endpoint: &String) -> Self{
+        NotificationsQueue { 
+            context: context.clone(), 
+            frontend_endpoint: frontend_endpoint.clone(), 
+            backend_endpoint: backend_endpoint.clone()
+        } 
+    }
+}
+
